@@ -293,6 +293,8 @@ def do_sync(conn_config, catalog, default_replication_method, state, state_file=
     sync_method_lookup, traditional_streams, logical_streams = \
         sync_method_for_streams(streams, state, default_replication_method)
 
+    LOGGER.info(f"logical_streams before: {logical_streams}")
+
     if currently_syncing:
         LOGGER.debug("Found currently_syncing: %s", currently_syncing)
 
@@ -316,6 +318,10 @@ def do_sync(conn_config, catalog, default_replication_method, state, state_file=
                                         sync_method_lookup[stream['tap_stream_id']],
                                         end_lsn)
 
+    _, _, logical_streams = sync_method_for_streams(streams, state, default_replication_method)
+
+    LOGGER.info(f"logical_streams after: {logical_streams}")
+
     logical_streams.sort(key=lambda s: metadata.to_map(s['metadata']).get(()).get('database-name'))
     for dbname, streams in itertools.groupby(logical_streams,
                                              lambda s: metadata.to_map(s['metadata']).get(()).get('database-name')):
